@@ -2,17 +2,17 @@ use strict;
 use warnings;
 
 package Template::Overlay;
-$Template::Overlay::VERSION = '1.06';
+$Template::Overlay::VERSION = '1.07';
 # ABSTRACT: A powerful, and simple, library for resolving placeholders in templated files
 # PODNAME: Template::Resolver
 
 use Carp;
-use File::Copy qw(cp);
+use File::Copy qw(copy);
 use File::Find;
 use File::Path qw(make_path);
 use File::Spec;
 use File::stat;
-use Fcntl ':mode';
+use Fcntl;
 use Log::Any;
 use Template::Overlay;
 
@@ -74,7 +74,7 @@ sub overlay {
                         $self->_resolve( $template, $file );
                     }
                     else {
-                        cp( $_, $file );
+                        copy( $_, $file );
                     }
                 }
             },
@@ -92,7 +92,10 @@ sub _resolve {
     my ( $self, $template, $file ) = @_;
 
     $logger->info( 'processing [', $template, '] -> [', $file, ']' );
-    open( my $handle, '>', $file ) || croak("open $file failed: $!");
+
+    my $mode = stat($template)->mode() & 07777;    ## no critic
+    sysopen( my $handle, $file, O_CREAT | O_WRONLY, $mode )
+        || croak("open $file failed: $!");
     eval {
         print( $handle $self->{resolver}->resolve(
                 filename => $template,
@@ -117,7 +120,7 @@ Template::Resolver - A powerful, and simple, library for resolving placeholders
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
